/*---------------------------------------------------------
 * Copyright (C) Microsoft Corporation. All rights reserved.
 *--------------------------------------------------------*/
var Path = require('path');
var _formatRegexp = /{(\d+)}/g;
function format(format) {
    var param = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        param[_i - 1] = arguments[_i];
    }
    return format.replace(_formatRegexp, function (match, paramIndex) {
        return typeof param[paramIndex] != 'undefined' ? param[paramIndex] : match;
    });
}
exports.format = format;
var _formatPIIRegexp = /{([^}]+)}/g;
function formatPII(format, excludePII, args) {
    return format.replace(_formatPIIRegexp, function (match, paramName) {
        if (excludePII && paramName.length > 0 && paramName[0] !== '_') {
            return match;
        }
        return args[paramName] && args.hasOwnProperty(paramName) ?
            args[paramName] :
            match;
    });
}
exports.formatPII = formatPII;
function random(low, high) {
    return Math.floor(Math.random() * (high - low) + low);
}
exports.random = random;
function isArray(what) {
    return Object.prototype.toString.call(what) === '[object Array]';
}
exports.isArray = isArray;
function endsWith(str, suffix) {
    return str.indexOf(suffix, str.length - suffix.length) !== -1;
}
exports.endsWith = endsWith;
function getPathRoot(p) {
    if (p) {
        if (p.length >= 3 && p[1] == ':' && p[2] == '\\' && ((p[0] >= 'a' && p[0] <= 'z') || (p[0] >= 'A' && p[0] <= 'Z'))) {
            return p.substr(0, 3);
        }
        if (p.length > 0 && p[0] == '/') {
            return '/';
        }
    }
    return null;
}
exports.getPathRoot = getPathRoot;
function makePathAbsolute(absPath, relPath) {
    return Path.resolve(Path.dirname(absPath), relPath);
}
exports.makePathAbsolute = makePathAbsolute;
function removeFirstSegment(path) {
    if (path[0] == Path.sep) {
        path = path.substr(1);
    }
    var pos = path.indexOf(Path.sep);
    if (pos >= 0) {
        path = path.substr(pos + 1);
    }
    else {
        return null;
    }
    if (path.length > 0) {
        return path;
    }
    return null;
}
exports.removeFirstSegment = removeFirstSegment;
function makeRelative(target, path) {
    var t = target.split(Path.sep);
    var p = path.split(Path.sep);
    var i = 0;
    for (; i < Math.min(t.length, p.length) && t[i] == p[i]; i++) {
    }
    var result = '';
    for (; i < p.length; i++) {
        result = Path.join(result, p[i]);
    }
    return result;
}
exports.makeRelative = makeRelative;
function extendObject(objectCopy, object) {
    for (var key in object) {
        if (object.hasOwnProperty(key)) {
            objectCopy[key] = object[key];
        }
    }
    return objectCopy;
}
exports.extendObject = extendObject;
//# sourceMappingURL=utilities.js.map