/*---------------------------------------------------------
 * Copyright (C) Microsoft Corporation. All rights reserved.
 *--------------------------------------------------------*/
'use strict';
define(["require", "exports", './xmlDef', 'monaco'], function (require, exports, languageDef, monaco) {
    function activate() {
        monaco.Modes.registerMonarchDefinition('xml', languageDef.language);
        var myWorker = monaco.Modes.loadInBackgroundWorker(require.toUrl('./xmlWorker.js'));
        function format(resource, range, options) {
            return myWorker.then(function (w) {
                var model = monaco.Services.ModelService.getModel(resource);
                var value = range ? model.getValueInRange(range) : model.getValue();
                if (value.length < 1024 * 1024) {
                    return w.beautify(value, {
                        indent_size: options.insertSpaces ? options.tabSize : 1,
                        indent_char: options.insertSpaces ? ' ' : '\t',
                        wrap_line_length: 256
                    });
                }
                else {
                    return null;
                }
            }).then(function (result) {
                if (result) {
                    return [{
                            range: range,
                            text: result
                        }];
                }
                else {
                    return null;
                }
            });
        }
        monaco.Modes.FormattingSupport.register('xml', {
            formatDocument: function (resource, options) {
                return format(resource, null, options);
            },
            formatRange: function (resource, range, options) {
                return format(resource, range, options);
            }
        });
    }
    exports.activate = activate;
});
//# sourceMappingURL=xmlMain.js.map